colour.notation — Colour 0.3.0 documentation

# Source code for colour.notation

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .dataset import *  # noqa
    from . import dataset
    from .munsell import MUNSELL_VALUE_METHODS
    from .munsell import munsell_value
    from .munsell import (
        munsell_value_priest1920,
        munsell_value_munsell1933,
        munsell_value_moon1943,
        munsell_value_saunderson1944,
        munsell_value_ladd1955,
        munsell_value_mccamy1987,
        munsell_value_ASTM_D1535_08)
    from .munsell import munsell_colour_to_xyY, xyY_to_munsell_colour

    __all__ = []
    __all__ += dataset.__all__
    __all__ += ['munsell_value']
    __all__ += ['MUNSELL_VALUE_METHODS']
    __all__ += ['munsell_value_priest1920',
                'munsell_value_munsell1933',
                'munsell_value_moon1943',
                'munsell_value_saunderson1944',
                'munsell_value_ladd1955',
                'munsell_value_mccamy1987',
                'munsell_value_ASTM_D1535_08']
    __all__ += ['munsell_colour_to_xyY', 'xyY_to_munsell_colour']